@@ -21,7 +21,7 @@ class AuthRouter:
         auth_db = 'default'
 
     def db_for_read(self, model, **hints):
-        if getattr(model.params, 'db'):
+        if hasattr(model, 'params') and getattr(model.params, 'db'):
             return getattr(model.params, 'db')
         if model._meta.db_table in self.route_db_tables:
             return self.auth_db
@@ -30,7 +30,7 @@ class AuthRouter:
         return None
 
     def db_for_write(self, model, **hints):
-        if getattr(model.params, 'db'):
+        if hasattr(model, 'params') and getattr(model.params, 'db'):
             return getattr(model.params, 'db')
         if model._meta.db_table in self.route_db_tables:
             return self.auth_db
